enumIntegerWidth
enum IntegerWidth
Restricted visibility: declared "@visibility root". Code outside that scope must not name this declaration.
Integer storage widths represented by the supported SQL dialects.
Cases
case Bits8case Bits16case Bits24case Bits32case Bits64Test cases 27
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 26
PostgreSqlEndToEndTestcallsSqliteIntegrationTestcallsDatabaseFixtureProviderTestcallsFileFixtureProviderTestcallsRowMaterializerTestcallsPlanGeneratorTestcallsRowGenerationTestcallsFixtureGeneratorTestcallsFixtureProviderTestcallsConstructorHydrationTestcallsPropertyHydrationTestcallsMySqlTypeMapperTestcallsColumnGeneratorTestcallsIntegerGeneratorTestcallsNumericGeneratorTestcallsPlatformFactoryTestcallsPostgreSqlTypeMapperTestcallsColumnGeneratorTestcallsNumericGeneratorTestcallsSqliteTypeMapperTestcallsColumnGeneratorTestcallsSqlSchemaProviderTestcallsIntegerRangeTest::providerSqlIntegerBoundscallsIntegerRangeTest::testDefaultSignednessIncludesNegativeValuescallsMySqlTypeMapperTestcallsTypeMapperInterfaceTestcalls
Relations
Constant reads 18
- class-const SqlFixture\Platform\MySql\Value\IntegerGenerator::generateTinyInt() packages/sql-fixture/src/Platform/MySql/Value/IntegerGenerator.php:28
- class-const SqlFixture\Platform\MySql\Value\IntegerGenerator::generateSmallInt() packages/sql-fixture/src/Platform/MySql/Value/IntegerGenerator.php:37
- class-const SqlFixture\Platform\MySql\Value\IntegerGenerator::generateMediumInt() packages/sql-fixture/src/Platform/MySql/Value/IntegerGenerator.php:46
- class-const SqlFixture\Platform\MySql\Value\IntegerGenerator::generateInt() packages/sql-fixture/src/Platform/MySql/Value/IntegerGenerator.php:55
- class-const SqlFixture\Platform\MySql\Value\IntegerGenerator::generateBigInt() packages/sql-fixture/src/Platform/MySql/Value/IntegerGenerator.php:64
- class-const SqlFixture\Platform\PostgreSql\Value\NumericGenerator::generate() packages/sql-fixture/src/Platform/PostgreSql/Value/NumericGenerator.php:28
- class-const SqlFixture\Platform\PostgreSql\Value\NumericGenerator::generate() packages/sql-fixture/src/Platform/PostgreSql/Value/NumericGenerator.php:29
- class-const SqlFixture\Platform\PostgreSql\Value\NumericGenerator::generate() packages/sql-fixture/src/Platform/PostgreSql/Value/NumericGenerator.php:30
- class-const SqlFixture\Platform\Sqlite\Value\ColumnGenerator::generateInteger() packages/sql-fixture/src/Platform/Sqlite/Value/ColumnGenerator.php:45
- class-const SqlFixture\Platform\Sqlite\Value\ColumnGenerator::generateInteger() packages/sql-fixture/src/Platform/Sqlite/Value/ColumnGenerator.php:46
- class-const SqlFixture\Platform\Sqlite\Value\ColumnGenerator::generateInteger() packages/sql-fixture/src/Platform/Sqlite/Value/ColumnGenerator.php:47
- class-const SqlFixture\Platform\Sqlite\Value\ColumnGenerator::generateInteger() packages/sql-fixture/src/Platform/Sqlite/Value/ColumnGenerator.php:48
- class-const SqlFixture\Platform\Sqlite\Value\ColumnGenerator::generateInteger() packages/sql-fixture/src/Platform/Sqlite/Value/ColumnGenerator.php:49
- class-const SqlFixture\TypeMapper\IntegerRange::__construct() packages/sql-fixture/src/TypeMapper/IntegerRange.php:30
- class-const SqlFixture\TypeMapper\IntegerRange::__construct() packages/sql-fixture/src/TypeMapper/IntegerRange.php:31
- class-const SqlFixture\TypeMapper\IntegerRange::__construct() packages/sql-fixture/src/TypeMapper/IntegerRange.php:32
- class-const SqlFixture\TypeMapper\IntegerRange::__construct() packages/sql-fixture/src/TypeMapper/IntegerRange.php:33
- class-const SqlFixture\TypeMapper\IntegerRange::__construct() packages/sql-fixture/src/TypeMapper/IntegerRange.php:34